<?php

namespace Kaizen_Coders\Url_Shortify;

/**
 * Class Promo
 *
 * Handle Promotional Campaign
 *
 * @package Kaizen_Coders\Url_Shortify
 *
 * @since 1.5.12.2
 */
class Promo {
	/**
	 * Initialize Promotions
	 *
	 * @since 1.5.12.2
	 */
	public function init() {
		add_action( 'admin_init', array( $this, 'dismiss_promotions' ) );
		add_action( 'admin_notices', array( $this, 'handle_promotions' ) );
	}

	/**
	 * Get Valid Promotions.
	 *
	 * @return string[]
	 *
	 * @since 1.5.12.2
	 */
	public function get_valid_promotions() {
		return array(
			'welcome_offer',
			'anniversary_offer'
		);
	}

	/**
	 * Dismiss Promotions.
	 *
	 * @since 1.5.12.2
	 */
	public function dismiss_promotions() {
		if ( isset( $_GET['kc_us_dismiss_admin_notice'] ) && $_GET['kc_us_dismiss_admin_notice'] == '1' && isset( $_GET['option_name'] ) ) {

			$option_name = sanitize_text_field( $_GET['option_name'] );

			$valid_options = $this->get_valid_promotions();

			if ( in_array( $option_name, $valid_options ) ) {

				update_option( 'kc_us_' . $option_name . '_dismissed', 'yes', false );

				if ( in_array( $option_name, $valid_options ) ) {
					wp_safe_redirect( US()->get_pricing_url() );
				} else {
					$referer = wp_get_referer();
					wp_safe_redirect( $referer );
				}
				exit();
			}
		}
	}
	/**
	 * Handle promotions activity.
	 *
	 * @since 1.5.12.2
	 */
	public function handle_promotions() {
		if ( ! US()->is_pro() ) {
			// On the 3rd day of installation & more than 3 short links created
			$installed_on = Option::get( 'installed_on', time() );
			$total_links  = US()->db->links->count();

			$days_after_installation = ( time() - $installed_on ) / 86400;

			$today = Helper::get_current_date_time();

			if ( $today >= '2022-05-11' &&
			     $today <= '2022-05-21' &&
			     $days_after_installation >= 2 &&
			     $total_links >= 1 &&
			     ! $this->is_promotion_dismissed( 'anniversary_offer' )
			) {
				$this->show_promotion('anniversary_offer');
			} else if ( $total_links >= 3 &&
			            $days_after_installation >= 10 &&
			            $days_after_installation <= 14 &&
			            ! $this->is_promotion_dismissed( 'welcome_offer' )
			) {
				$this->show_promotion('welcome_offer');
			}
		}
	}

	/**
	 * Show Promotion.
	 *
	 * @param $promotion
	 *
	 * @since 1.5.12.2
	 */
	public function show_promotion( $promotion ) {
		?>
		<style type="text/css">
            .kc_us_offer {
                width: 55%;
                margin: 0 auto;
                text-align: center;
                padding-top: 1.2em;
            }

		</style>

		<!-- Display Campaign -->
        <!-- Ideal size for campaign image is 800x50, 800x100. Don't use more height image. -->
		<div class="kc_us_offer">
			<a target="_blank" href="?kc_us_dismiss_admin_notice=1&option_name=<?php echo $promotion; ?>"><img
					src="<?php echo KC_US_PLUGIN_ASSETS_DIR_URL; ?>/images/promo/<?php echo $promotion; ?>.png" /></a>
		</div>

		<?php
	}

	/**
	 * Is Promo displayed and dismissed by user?
	 *
	 * @param $promo
	 *
	 * @return bool
	 *
	 * @since 1.5.12.2
	 */
	public function is_promotion_dismissed($promotion) {
		if(empty($promotion)) {
			return false;
		}

		$promotion_dismissed_option = 'kc_us_' . trim($promotion) . '_dismissed';

		return 'yes' === get_option($promotion_dismissed_option);
	}
}
